
identityProviders = ['microsoft','google','facebook','linkedin','slack','twitter','github','quickbooks','onelogin','okta','apple','basecamp','dropbox','fitbit','planningcenter','twitch']

eventTypes = ['LocalLogin', 'LocalLogout']

localVallidationValues = ['pass', 'fail', 'notapplicable']

forceAuthenticationTypes = ['off', 'attempt', 'force']